==> mauticGIT-Test-20251212_104643.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/62/622bc0bf99fbeb6a66b0f11f3656983d.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-icons_888888_256x240.png */
class __TwigTemplate_54538c822af6cbf78606589f1538f305 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000\000\000\000\000\000\000\000Er@\000\000\000gAMA\000\000a\000\000\000 cHRM\000\000z&\000\000\000\000\000\000\000\000\000u0\000\000`\000\000:\000\000pQ<\000\000\000bKGD\000I( \000\000\000tIME
%'E\000\000IDATx{eE}?H(bX!²[R`JH!wMbݱFѨh\000ڥXT#D
T;\"baRqw}G)b}N9νsOsϯOw~8<3@@F3 
\$\000\t+\\\$\tOok؞0Z\t\"\"`JyQ\000zB7iQ'.q\000IvCT2mk5e[7Gtͩk!HL^?3dJ[
fZS0Ms}`T8tUS˴
@1a`fekï6^\000/\000
@px{|AQ\"iO=]}=\\z\\mc-ܷ>(DЯ'L6=;㴓lۧ=M/>ڠ̓6(ڬ0\$%GI_km+\$.q
W7~!pxh8\0004^\000/\000
ƐQG8UkV}A 栺*s\000%~\000aJYT}-c*vۭ.J=C
`+~P\000}\\=.43%4Ph
F,_\\ֱWRЃ>4j\"mhi@IzJҼy
tsY@e\000e'C뱅rjm܍C&[LM%m{e^.%flNźuѶd{\$*\"nK9(ufc/ӯ<-!LUi\000{&0lWW/\000
@pxh8͡phxѮO)L\000Q.ޫU@P--[jj6ƵKǎɟ5r\t7phۊ{]Zn!w3ڹRzz[ta.m[uD,i9ХcwnϹCzƠ Gm,o}RfNaÔ\000
Juˁ
]oۯ-M\000u`f]\000gJ(U@E N=Mϯ,U `z~S=n0o粤=\t̙hJC,K\000Js /&޸咲C9Uhuav^u9&mtjc(0H@ᗂ/\000
@kR]y{\000L*k,CV=\t&*aTW;uMB-b5߮`bp]Ӵy4ttClhbٔއA/(qW\\;\000ȊG'+? U@낢sBd *
Ȱ\$=U!zӊUO{'!`5͔:KU=@mRal{IB%b5}ZƀT7\t셲jDe!014]Fh\0004^\000/\000
@1|Ef /\000nl&tBnȫؠ 
ʹwSLODHZpU]g@\000*y;i-JӅR޽HCt5jNާr\tLs_S>ܵG]ϗ-
򩸹h_Y=^4Y\tkNջNc>BGA\"\000I՚L@<4AG<!s\"=;a[@ȼUw0b?X\t=0Hjr~zV(U&v\$>R@P骁lO\$H!`;pdvY\$4m^U_B`ڑyP0l'z&m0Oౡpxh8\0004\$\000Jl_ҿAw`\\qcM
!OJe8|z==[K<.iǸ\"0kޘW=r)0O1%^q&l
;GX)[ʝυc\tCUrH=Ž1eq3<qm
LZP(DV2K~\000,y)xQ@ezRBc\"~߲\000Dɔ\"2'Zo|88ۀWa5pTa,i1Y\000\"@)?ӆ߻!b/\$\000y
rH\000C*sY+r(󰍋x!i{@:>PRN%F./TDUC|'ȔՇx \000;w1ws:?r^fOE1~6\tY\\U\000h&( 80h'yW'w(:*yMjmv/\t{pnx/(?_iRz5^z\000,f\\
,OsxYM`/*6;x\000g2Ë%sW2ial!ަ)9ϣՕAE~5]f\"G\"z
^`[[UE0C!f ,h5c5Cm:X@`I\000bSdshyeQwB~+`\$;\\l<Arz\$\" D/~?Ue!\$\000(<*@px-<.3 @ac.'oaVQtŷ_޲p~X\\Q[t/X꧓[_(f,RC|
leWx1L)չϰ8K*wD/n-
}ߑB|W}|·z&\000\$u7@}L&ip=
gjw)^LZ/
@HV=5eO~7)T,9TA'nT=~E<6:LW8~GIO,Y\tHnJ#\\xAXNS癫EҥX'9!fg7\\b˅|K6T>c#%V]I%uB59ů9\\
@L\000VIT5lΜoavY~/zq,b/쇗/&oMޮPH:`oaLc\$1>a_~EvQ5yK
wہ]V\000\\MbL}n{7_\$_f@M?g|vhЇOiT=wx96MRD?Pd3ddco/\\=Zy*N֫Ig/7؜(86~bC2XSɇv>G[UBuSf%&?g.\000n^[\$CA9D`}O&R5jQ|O c]z@hd}
vnAsw\$S&qNw8BHH.al/.uS?-¯[
Qߍ0~-ӗ쏌}dK@3>Lb,㺪k,OxAJL
Q\000
4^\000/\000
yU4TtUm`:!E0ݮu\\k_A>>^Ż
1y(u.pnf>NȭJǹ\"o͐g(m!dz5p휝=Nن~Y/1YP,DO>٩E {Q\\)|uz}(BOU#/}WH6gvs!Pf^3dB3uBJ|ye0\t,p%dA\000Nؙ\"oԧE~)_Fxq/O^_V=gOw\tV.+\"8<g''d颹)cRDzIZXE|7F(S@;fqYw\\Sc^sgqƕ-vE}ta;K3!yo`10wUMcʢ
òZ]!Np⿖tz[8]L.IH⯀H1EU?\000~Ιl6ngs9;uW0QK|#h'_iDu5F4xVFt?@TC\0007Cln6p6UvE9V9rf\t1k\t`[6\"AvE'xxhQJs998_Sq/\\ALvIl_DN3t&c,{ou'p\0002M1>JZ˿5F-?>oʅؖT^r ZJjhFnm9zޭν:y0c?]yUm-~C/d|l7?
e_>DѡW_ִ%XZ5\000,./\000
Gt\0004^\000\000_Agܣ7ˁsE!ܧW*Agޣ>\000p9rNٟнQ\$=f?qb_fƅd\000\t&(_5q^ϒ`_ƳCNEDs\t@Xd6\\hl^͍B,19M2^G
\000-WCf[X.I!n?.3_Ppǹ@}d@'3d>U?RI:}]\000k<`\\LXfSX Y
 E㶎ho~scv=C`x+!bc;y6SiqRN, :WqUw;9~8cS_\\w'^xq'c:QFf߷~,%}ϠW';[=Z6^\$!E\$\000'-vs+sU(tgMÁ\000,Qh<1cXIxm`pxh8\0004^\000Xo26nQHAI4;F[ՒaA*jdҦa=4tX/,~RJ*o-O]UŪiS +8³*dބC)^H~M?\000f{lC
]GG %П֡ΨYT\000O\t\000BٯyXR\t>F/XכI,*YS/
(`}\000D,(KXgp4bZD'OWh+RCCMyЍYs'!nJCC#\\r=hLݔï6^\000/\000
@Ñ\000[93\000\\;4[C#=G=6!hMݏ^NW9:,so0Cd!8;2&s\\KtŽl:-*%A\$\000-G94?B8=:5FTcw[8͖?kxkj/~}cn\"]\000o.0x+>`/]ޭ\0005\000.`+g(\"Fers\"bۍ+\"xxp=NKLBg[y E?Ga*J\$su̟2\$JLqW3[77CD\0000~ķx%>1 X)Ϲ
G`j!gFoprpxh82PR
^[~F:.f~o8\000\\#u]y
K\t|@4dmSQ\\WӣeWC|[V~[OItMt1RDU͕lw؃zwp]Wv`
鑫K~-ְ|1t40wq>PsߜIdhE%u]\\1{ΘM`OpV\$ /#=65ك|S~XB!~_1j])}S/G\" C@4\tF_&Dxv{\\(rݯHj\$+oد~jIDpT@+yz;6~hoK?B?o˿)~yUY: uRD\"GYNK.F޶a~o\000s8KGY/pu}l42AHᵁ
@pxh8Deta{T
O)Cץ{C@=PS\000qHO3`cΗwC\000鑇=B_nPQ!`B*rls
گM<JBd[@P漀a{T_j8\0004^\000/\000
@ñyzY\000꯳2|Y@xT,\000{ϠakWQ,\000+\$\t[!\\{vSaOz1L\000=l*+ʶ\000O9oOؿH_s^A\000S'eM)';#]BeA@d{=@}؏p*&G)[@j)B~?mVieƝ~ۣ&c<z6H~\000\000\000%tEXtdate:create\0002016-09-14T13:32:39-04:00z\000\000\000%tEXtdate:modify\0002015-06-01T10:37:21-04:00(An\000\000\000tEXtSoftware\000Adobe ImageReadyqe<\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-icons_888888_256x240.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-icons_888888_256x240.png", "/var/www/mautic-ktn/app/bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-icons_888888_256x240.png");
    }
}

==> mauticGIT-Test-20260116_092227.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/62/622bc0bf99fbeb6a66b0f11f3656983d.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-icons_888888_256x240.png */
class __TwigTemplate_54538c822af6cbf78606589f1538f305 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000\000\000\000\000\000\000\000Er@\000\000\000gAMA\000\000a\000\000\000 cHRM\000\000z&\000\000\000\000\000\000\000\000\000u0\000\000`\000\000:\000\000pQ<\000\000\000bKGD\000I( \000\000\000tIME
%'E\000\000IDATx{eE}?H(bX!²[R`JH!wMbݱFѨh\000ڥXT#D
T;\"baRqw}G)b}N9νsOsϯOw~8<3@@F3 
\$\000\t+\\\$\tOok؞0Z\t\"\"`JyQ\000zB7iQ'.q\000IvCT2mk5e[7Gtͩk!HL^?3dJ[
fZS0Ms}`T8tUS˴
@1a`fekï6^\000/\000
@px{|AQ\"iO=]}=\\z\\mc-ܷ>(DЯ'L6=;㴓lۧ=M/>ڠ̓6(ڬ0\$%GI_km+\$.q
W7~!pxh8\0004^\000/\000
ƐQG8UkV}A 栺*s\000%~\000aJYT}-c*vۭ.J=C
`+~P\000}\\=.43%4Ph
F,_\\ֱWRЃ>4j\"mhi@IzJҼy
tsY@e\000e'C뱅rjm܍C&[LM%m{e^.%flNźuѶd{\$*\"nK9(ufc/ӯ<-!LUi\000{&0lWW/\000
@pxh8͡phxѮO)L\000Q.ޫU@P--[jj6ƵKǎɟ5r\t7phۊ{]Zn!w3ڹRzz[ta.m[uD,i9ХcwnϹCzƠ Gm,o}RfNaÔ\000
Juˁ
]oۯ-M\000u`f]\000gJ(U@E N=Mϯ,U `z~S=n0o粤=\t̙hJC,K\000Js /&޸咲C9Uhuav^u9&mtjc(0H@ᗂ/\000
@kR]y{\000L*k,CV=\t&*aTW;uMB-b5߮`bp]Ӵy4ttClhbٔއA/(qW\\;\000ȊG'+? U@낢sBd *
Ȱ\$=U!zӊUO{'!`5͔:KU=@mRal{IB%b5}ZƀT7\t셲jDe!014]Fh\0004^\000/\000
@1|Ef /\000nl&tBnȫؠ 
ʹwSLODHZpU]g@\000*y;i-JӅR޽HCt5jNާr\tLs_S>ܵG]ϗ-
򩸹h_Y=^4Y\tkNջNc>BGA\"\000I՚L@<4AG<!s\"=;a[@ȼUw0b?X\t=0Hjr~zV(U&v\$>R@P骁lO\$H!`;pdvY\$4m^U_B`ڑyP0l'z&m0Oౡpxh8\0004\$\000Jl_ҿAw`\\qcM
!OJe8|z==[K<.iǸ\"0kޘW=r)0O1%^q&l
;GX)[ʝυc\tCUrH=Ž1eq3<qm
LZP(DV2K~\000,y)xQ@ezRBc\"~߲\000Dɔ\"2'Zo|88ۀWa5pTa,i1Y\000\"@)?ӆ߻!b/\$\000y
rH\000C*sY+r(󰍋x!i{@:>PRN%F./TDUC|'ȔՇx \000;w1ws:?r^fOE1~6\tY\\U\000h&( 80h'yW'w(:*yMjmv/\t{pnx/(?_iRz5^z\000,f\\
,OsxYM`/*6;x\000g2Ë%sW2ial!ަ)9ϣՕAE~5]f\"G\"z
^`[[UE0C!f ,h5c5Cm:X@`I\000bSdshyeQwB~+`\$;\\l<Arz\$\" D/~?Ue!\$\000(<*@px-<.3 @ac.'oaVQtŷ_޲p~X\\Q[t/X꧓[_(f,RC|
leWx1L)չϰ8K*wD/n-
}ߑB|W}|·z&\000\$u7@}L&ip=
gjw)^LZ/
@HV=5eO~7)T,9TA'nT=~E<6:LW8~GIO,Y\tHnJ#\\xAXNS癫EҥX'9!fg7\\b˅|K6T>c#%V]I%uB59ů9\\
@L\000VIT5lΜoavY~/zq,b/쇗/&oMޮPH:`oaLc\$1>a_~EvQ5yK
wہ]V\000\\MbL}n{7_\$_f@M?g|vhЇOiT=wx96MRD?Pd3ddco/\\=Zy*N֫Ig/7؜(86~bC2XSɇv>G[UBuSf%&?g.\000n^[\$CA9D`}O&R5jQ|O c]z@hd}
vnAsw\$S&qNw8BHH.al/.uS?-¯[
Qߍ0~-ӗ쏌}dK@3>Lb,㺪k,OxAJL
Q\000
4^\000/\000
yU4TtUm`:!E0ݮu\\k_A>>^Ż
1y(u.pnf>NȭJǹ\"o͐g(m!dz5p휝=Nن~Y/1YP,DO>٩E {Q\\)|uz}(BOU#/}WH6gvs!Pf^3dB3uBJ|ye0\t,p%dA\000Nؙ\"oԧE~)_Fxq/O^_V=gOw\tV.+\"8<g''d颹)cRDzIZXE|7F(S@;fqYw\\Sc^sgqƕ-vE}ta;K3!yo`10wUMcʢ
òZ]!Np⿖tz[8]L.IH⯀H1EU?\000~Ιl6ngs9;uW0QK|#h'_iDu5F4xVFt?@TC\0007Cln6p6UvE9V9rf\t1k\t`[6\"AvE'xxhQJs998_Sq/\\ALvIl_DN3t&c,{ou'p\0002M1>JZ˿5F-?>oʅؖT^r ZJjhFnm9zޭν:y0c?]yUm-~C/d|l7?
e_>DѡW_ִ%XZ5\000,./\000
Gt\0004^\000\000_Agܣ7ˁsE!ܧW*Agޣ>\000p9rNٟнQ\$=f?qb_fƅd\000\t&(_5q^ϒ`_ƳCNEDs\t@Xd6\\hl^͍B,19M2^G
\000-WCf[X.I!n?.3_Ppǹ@}d@'3d>U?RI:}]\000k<`\\LXfSX Y
 E㶎ho~scv=C`x+!bc;y6SiqRN, :WqUw;9~8cS_\\w'^xq'c:QFf߷~,%}ϠW';[=Z6^\$!E\$\000'-vs+sU(tgMÁ\000,Qh<1cXIxm`pxh8\0004^\000Xo26nQHAI4;F[ՒaA*jdҦa=4tX/,~RJ*o-O]UŪiS +8³*dބC)^H~M?\000f{lC
]GG %П֡ΨYT\000O\t\000BٯyXR\t>F/XכI,*YS/
(`}\000D,(KXgp4bZD'OWh+RCCMyЍYs'!nJCC#\\r=hLݔï6^\000/\000
@Ñ\000[93\000\\;4[C#=G=6!hMݏ^NW9:,so0Cd!8;2&s\\KtŽl:-*%A\$\000-G94?B8=:5FTcw[8͖?kxkj/~}cn\"]\000o.0x+>`/]ޭ\0005\000.`+g(\"Fers\"bۍ+\"xxp=NKLBg[y E?Ga*J\$su̟2\$JLqW3[77CD\0000~ķx%>1 X)Ϲ
G`j!gFoprpxh82PR
^[~F:.f~o8\000\\#u]y
K\t|@4dmSQ\\WӣeWC|[V~[OItMt1RDU͕lw؃zwp]Wv`
鑫K~-ְ|1t40wq>PsߜIdhE%u]\\1{ΘM`OpV\$ /#=65ك|S~XB!~_1j])}S/G\" C@4\tF_&Dxv{\\(rݯHj\$+oد~jIDpT@+yz;6~hoK?B?o˿)~yUY: uRD\"GYNK.F޶a~o\000s8KGY/pu}l42AHᵁ
@pxh8Deta{T
O)Cץ{C@=PS\000qHO3`cΗwC\000鑇=B_nPQ!`B*rls
گM<JBd[@P漀a{T_j8\0004^\000/\000
@ñyzY\000꯳2|Y@xT,\000{ϠakWQ,\000+\$\t[!\\{vSaOz1L\000=l*+ʶ\000O9oOؿH_s^A\000S'eM)';#]BeA@d{=@}؏p*&G)[@j)B~?mVieƝ~ۣ&c<z6H~\000\000\000%tEXtdate:create\0002016-09-14T13:32:39-04:00z\000\000\000%tEXtdate:modify\0002015-06-01T10:37:21-04:00(An\000\000\000tEXtSoftware\000Adobe ImageReadyqe<\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-icons_888888_256x240.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-icons_888888_256x240.png", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-icons_888888_256x240.png");
    }
}
